@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: bbs_thread_ui.c,v 1.51 2003/12/13 07:21:06 fuyu Exp $
+ * $Id: bbs_thread_ui.c,v 1.53 2003/12/15 15:20:07 fuyu Exp $
  */
 
 #include "config.h"
@@ -79,6 +79,9 @@ static void write_response_cb(BBSThreadView *view,
 static void interactive_search_cb(BBSThreadView *view,
 				  BBSThreadViewSearchAction action,
 				  OchushaApplication *application);
+static void save_initial_thread_view_position(BBSThreadView *view,
+					      BBSThreadGUIInfo *info,
+					      GtkTextMark *mark);
 
 static void show_popup(OchushaApplication *application,
 		       OchushaBBSThread *thread,
@@ -632,6 +635,38 @@ ensure_bbs_thread_info(OchushaBBSThread *thread)
 }
 
 
+void
+specify_thread_view_point(OchushaBBSThread *thread, PanedNotebook *board_view,
+			  int res_num)
+{
+  BBSThreadGUIInfo *info = ensure_bbs_thread_info(thread);
+  BBS_THREAD_UI_LOCK
+  {
+    int offset;
+    /*
+     * ȡɽϤĤˤʤ
+     */
+    info->res_num = res_num;
+    if (info->rendering_done && info->last_read != NULL
+	&& res_num < info->offsets_length
+	&& (offset = info->offsets[res_num - 1]) > 0)
+      {
+	GtkWidget *scrolled_window
+	  = paned_notebook_get_item_view(board_view, thread);
+	if (scrolled_window != NULL)
+	  {
+	    BBSThreadView *thread_view
+	      = BBS_THREAD_VIEW(gtk_bin_get_child(GTK_BIN(scrolled_window)));
+	    GtkTextMark *mark
+	      = bbs_thread_view_create_mark_at_offset(thread_view, offset);
+	    save_initial_thread_view_position(thread_view, info, mark);
+	  }
+      }
+  }
+  BBS_THREAD_UI_UNLOCK
+}
+
+
 typedef struct _BBSThreadJobArgs
 {
   OchushaApplication *application;
@@ -1137,7 +1172,7 @@ typedef struct _ScrollToMarkArgs
 } ScrollToMarkArgs;
 
 
-gboolean
+static gboolean
 scroll_to_mark_on_idle(ScrollToMarkArgs *args)
 {
   gdk_threads_enter();
@@ -1156,7 +1191,10 @@ static void
 save_initial_thread_view_position(BBSThreadView *view, BBSThreadGUIInfo *info,
 				  GtkTextMark *mark)
 {
-  ScrollToMarkArgs *args = G_NEW0(ScrollToMarkArgs, 1);
+  ScrollToMarkArgs *args;
+  g_return_if_fail(IS_BBS_THREAD_VIEW(view) && info != NULL && mark != NULL);
+
+  args = G_NEW0(ScrollToMarkArgs, 1);
   info->next_mark = mark;
   args->view = view;
   args->info = info;
@@ -1348,6 +1386,7 @@ render_bbs_thread(WorkerThread *employee, gpointer args)
       BBS_THREAD_UI_LOCK
       {
 	info->rendering_done = TRUE;
+	info->res_num = 0;
       }
       BBS_THREAD_UI_UNLOCK;
       return;
@@ -1470,7 +1509,7 @@ start_thread_rendering(OchushaBBSThread *thread, const gchar *title,
 {
   RendererContext *context = (RendererContext *)user_data;
   BBSThreadView *view = context->view;
-  BBSThreadGUIInfo *info;
+  BBSThreadGUIInfo *info = ensure_bbs_thread_info(context->thread);
 
 #if DEBUG_GUI_MOST
   fprintf(stderr, "start_rendering\n");
@@ -1478,22 +1517,11 @@ start_thread_rendering(OchushaBBSThread *thread, const gchar *title,
 
   gdk_threads_enter();
 
-  if (context->last_read_number == 0)
+  if (context->last_read_number == 0 && info->res_num == 0)
     {
       /* ɤॹξ祿ȥߤˤΤǤ˥ޡդ롣*/
-      info = ensure_bbs_thread_info(context->thread);
       info->last_read = bbs_thread_view_create_mark(view);
-#if 0
-      /* ɤॹξϡޡľΥ֤ĴᤷΤǡ
-       * ȥߤ˾ޤ֤ɽƤ롣ʤΤǡٱ
-       * ɬפʤ桼ɤ߻ϤƤ礬¿
-       * Τǡष⡣
-       */
-      save_initial_thread_view_position(view, info, info->last_read);
-#endif
     }
-  else
-    info = NULL;
 
   bbs_thread_view_push_tag(view, context->thread_title_tag);
 
@@ -1502,9 +1530,8 @@ start_thread_rendering(OchushaBBSThread *thread, const gchar *title,
 
   bbs_thread_view_pop_tags(view, context->thread_title_tag);
 
-  if (context->last_read_number == 0)
+  if (info->last_read != NULL)
     {
-      g_assert(info != NULL);
       /* save_initial_thread_view_position(...)򤷤ʤȡ
        * 碌ƥ뤷ƤޤȤΤǡŪ
        * ƬŽդ롣
@@ -1563,11 +1590,17 @@ render_response(OchushaBBSThread *thread, gint number,
       info->offsets[number] = bbs_thread_view_get_current_offset(view);
     }
 
+  if (number == info->res_num)
+    {
+      GtkTextMark *mark = bbs_thread_view_create_mark(view);
+      save_initial_thread_view_position(view, info, mark);
+    }
+
   if (number == context->last_read_number)
     {
-      /* ɥ쥹*/
       info->last_read = bbs_thread_view_create_mark(view);
-      save_initial_thread_view_position(view, info, info->last_read);
+      if (info->res_num == 0)
+	save_initial_thread_view_position(view, info, info->last_read);
     }
 
   if (thread->number_of_responses_read < number)
@@ -1583,17 +1616,6 @@ render_response(OchushaBBSThread *thread, gint number,
 
   gdk_threads_enter();
 
-#if ENABLE_RENDERING_ON_IDLE
-  while (!try_get_rendering_right(context->application,
-				  info->response_source_buffer,
-				  thread))
-    {
-      gdk_threads_leave();
-      ochusha_async_buffer_wait(info->response_source_buffer,
-				"bbs_thread_ui.c: each_response_cb()");
-      gdk_threads_enter();
-    }
-#endif
   bbs_thread_view_push_tag(view, context->response_header_tag);
   bbs_thread_view_append_text(view, buffer, -1);
   bbs_thread_view_append_text(view, LARGE_COLON, 3);
@@ -1750,11 +1772,17 @@ render_broken_response(OchushaBBSThread *thread, gint number,
       info->offsets[number] = bbs_thread_view_get_current_offset(view);
     }
 
+  if (number == info->res_num)
+    {
+      GtkTextMark *mark = bbs_thread_view_create_mark(view);
+      save_initial_thread_view_position(view, info, mark);
+    }
+  
   if (number == context->last_read_number)
     {
-      /* ɥ쥹*/
       info->last_read = bbs_thread_view_create_mark(view);
-      save_initial_thread_view_position(view, info, info->last_read);
+      if (info->res_num == 0)
+	save_initial_thread_view_position(view, info, info->last_read);
     }
 
   if (thread->number_of_responses_read < number)
@@ -1767,17 +1795,6 @@ render_broken_response(OchushaBBSThread *thread, gint number,
 
   gdk_threads_enter();
 
-#if ENABLE_RENDERING_ON_IDLE
-  while (!try_get_rendering_right(context->application,
-				  info->response_source_buffer,
-				  thread))
-    {
-      gdk_threads_leave();
-      ochusha_async_buffer_wait(info->response_source_buffer,
-				"bbs_thread_ui.c: each_response_cb()");
-      gdk_threads_enter();
-    }
-#endif
   bbs_thread_view_append_text(view, buffer, -1);
   bbs_thread_view_append_text(view, LARGE_COLON, 3);
   bbs_thread_view_append_text(view, LARGE_COLON, 3);
@@ -1815,19 +1832,20 @@ end_thread_rendering(OchushaBBSThread *thread, gboolean finished,
       bbs_thread_view_clear(view);
       gdk_threads_leave();
     }
-  else if (info->last_read == NULL)
+  else
     {
-      /*
-       * MEMO: ͭʤ
-       *       äޤǤϿ쥹Ƭ˥ޡդƤΤǡ
-       *       쥹ʤȥޡʤˤʤäƤޤΤǤ
-       *       ХåեκǸ˥ޡĤƤ
-       */
-      info->last_read = bbs_thread_view_create_mark(view);
-      save_initial_thread_view_position(view, info, info->last_read);
+      if (info->last_read == NULL)
+	{
+	  /*
+	   * MEMO: ꤨ͡Ĥꡣ
+	   */
+	  info->last_read = bbs_thread_view_create_mark(view);
+	  save_initial_thread_view_position(view, info, info->last_read);
 #if DEBUG_GUI
-      fprintf(stderr, "end_thread_rendering: What's happen?\n");
+	  fprintf(stderr, "end_thread_rendering: What's happen?\n");
 #endif
+	}
+      info->res_num = 0;
     }
 
 #if DEBUG_GUI_MOST
@@ -1924,6 +1942,8 @@ start_element_cb(void *user_data, const char *name, const char *const attrs[])
 #endif
 	    break;
 	  }
+	else
+	  i++;
 
       if (link == NULL)
 	link = G_STRDUP(_("*empty link*"));
