@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: bbs_thread_ui.h,v 1.13 2003/12/12 21:43:52 fuyu Exp $
+ * $Id: bbs_thread_ui.h,v 1.14 2003/12/14 19:04:36 fuyu Exp $
  */
 
 #ifndef _BBSTHREAD_UI_H_
@@ -34,6 +34,7 @@
 #include "ochusha_ui.h"
 #include "ochusha_bbs_thread.h"
 #include "ochusha_async_buffer.h"
+#include "paned_notebook.h"
 #include "threadlist_view.h"
 #include "icon_label.h"
 
@@ -62,6 +63,9 @@ typedef struct _BBSThreadGUIInfo
   /* ɽ(ThreadlistEntryFlagsORȤä) */
   int view_flags;
 
+  /* 򳫤ɽ쥹ֹ(0:ϴ) */
+  int res_num;
+
   /* ᥤ򥹥ɽϤʸȤɽ뤫ɤ */
   ThreadViewMailtoMode show_mailto_mode;
 
@@ -112,6 +116,8 @@ typedef struct _BBSThreadGUIInfo
 void prepare_thread_ui_initialization(OchushaApplication *application);
 void initialize_thread_ui(OchushaApplication *application);
 BBSThreadGUIInfo * ensure_bbs_thread_info(OchushaBBSThread *thread);
+void specify_thread_view_point(OchushaBBSThread *thread,
+			       PanedNotebook *board_view, int res_num);
 GtkWidget *open_bbs_thread(OchushaApplication *application,
 			   OchushaBBSThread *thread, IconLabel *tab_label);
 
