@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: boardlist_ui.c,v 1.35 2003/12/07 16:57:58 fuyu Exp $
+ * $Id: boardlist_ui.c,v 1.36 2003/12/12 21:43:52 fuyu Exp $
  */
 
 #include "config.h"
@@ -49,12 +49,10 @@
 
 #include <errno.h>
 
-#if ENABLE_ONIGURUMA
-# if HAVE_ONIG_ONIGPOSIX_H
-#  include <onig/onigposix.h>
-# else
-#  include <onigposix.h>
-# endif
+#if HAVE_ONIG_ONIGPOSIX_H
+# include <onig/onigposix.h>
+#else
+# include <onigposix.h>
 #endif
 
 #include <stdio.h>
@@ -591,10 +589,8 @@ static ThreadlistSearchQueryData search_query_data =
   NULL,		/* key */
   TEXT_SEARCH_DIRECTION_DOWN,
   NULL,		/* last_view */
-#if ENABLE_ONIGURUMA
   {},		/* regexp */
   FALSE,	/* regexp_available */
-#endif
   FALSE,	/* enable_wrap */
   FALSE,	/* match_case */
   FALSE,	/* use_regexp */
@@ -695,7 +691,6 @@ text_search_window_query_changed_cb(TextSearchWindow *window, const gchar *key,
   search_query_data.direction = direction;
   search_query_data.enable_wrap = enable_wrap;
   search_query_data.match_case = match_case;
-#if ENABLE_ONIGURUMA
   search_query_data.use_regexp = use_regexp;
   if (use_regexp)
     {
@@ -717,10 +712,6 @@ text_search_window_query_changed_cb(TextSearchWindow *window, const gchar *key,
     }
   else
     result = do_search_on_current_threadlist(application, TRUE);
-#else
-  search_query_data.use_regexp = FALSE;
-  result = do_search_on_current_threadlist(application, TRUE);
-#endif
 
   return result;
 }
@@ -1140,6 +1131,27 @@ boardlist_read_board_element_cb(OchushaBBSTable *table,
 						       "last_name");
   info->last_mail = ochusha_utils_get_attribute_string(board_attributes,
 						       "last_mail");
+
+  info->board_local_a_bone
+    = ochusha_utils_get_attribute_boolean(board_attributes,
+					  "board_local_a_bone");
+  info->a_bone_by_name
+    = ochusha_utils_get_attribute_boolean(board_attributes, "a_bone_by_name");
+  info->a_bone_by_name_pattern
+    = ochusha_utils_get_attribute_string(board_attributes,
+					 "a_bone_by_name_pattern");
+  info->a_bone_by_id
+    = ochusha_utils_get_attribute_boolean(board_attributes,
+					  "a_bone_by_id");
+  info->a_bone_by_id_pattern
+    = ochusha_utils_get_attribute_string(board_attributes,
+					 "a_bone_by_id_pattern");
+  info->a_bone_by_content
+    = ochusha_utils_get_attribute_boolean(board_attributes,
+					  "a_bone_by_content");
+  info->a_bone_by_content_pattern
+    = ochusha_utils_get_attribute_string(board_attributes,
+					 "a_bone_by_content_pattern");
   return;
 }
 
@@ -1209,6 +1221,19 @@ boardlist_write_board_element_cb(OchushaBBSTable *table,
       OUTPUT_BOARD_ATTRIBUTE_INT(boardlist_xml, info, filter.ignore_threshold);
     }
 
+  if (info->board_local_a_bone)
+    {
+      OUTPUT_BOARD_ATTRIBUTE_BOOLEAN(boardlist_xml, info, board_local_a_bone);
+      OUTPUT_BOARD_ATTRIBUTE_BOOLEAN(boardlist_xml, info, a_bone_by_name);
+      OUTPUT_BOARD_ATTRIBUTE_STRING(boardlist_xml, info,
+				    a_bone_by_name_pattern);
+      OUTPUT_BOARD_ATTRIBUTE_BOOLEAN(boardlist_xml, info, a_bone_by_id);
+      OUTPUT_BOARD_ATTRIBUTE_STRING(boardlist_xml, info, a_bone_by_id_pattern);
+      OUTPUT_BOARD_ATTRIBUTE_BOOLEAN(boardlist_xml, info, a_bone_by_content);
+      OUTPUT_BOARD_ATTRIBUTE_STRING(boardlist_xml, info,
+				    a_bone_by_content_pattern);
+    }
+
   return;
 }
 
