@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: bulletin_board_ui.c,v 1.69 2003/12/12 21:43:52 fuyu Exp $
+ * $Id: bulletin_board_ui.c,v 1.71 2003/12/15 17:34:33 fuyu Exp $
  */
 
 #include "config.h"
@@ -862,13 +862,10 @@ open_thread_view(WorkerThread *employee, gpointer job_args)
       }
 
 #if DEBUG_GUI_MOST
-    fprintf(stderr, "Thread ID (e.g. DAT file name): \"%s\"\n",
+    fprintf(stderr, "Thread ID: \"%s\"\n",
 	    args->thread_id);
 #endif
     /* λǡ٤Ϻ줿Ȥݾڤ */
-#if 0
-    thread = g_hash_table_lookup(board->thread_table, args->thread_id);
-#endif
 
     if (thread != NULL)
       {
@@ -878,8 +875,8 @@ open_thread_view(WorkerThread *employee, gpointer job_args)
 	/* TODO:
 	 * (board_view != NULL && thread == NULL)ʤ顢¿ʬΥDAT
 	 * 긵˥å夷ƤʬȤäƼɽǤ褦ˤ
-	 * ޤargs->res_numλȤƻͤ褦
 	 */
+	specify_thread_view_point(thread, board_view, args->res_num);
 
 	if (board_view != NULL)
 	  paned_notebook_open_item_view(board_view, thread, args->in_tab);
@@ -1093,18 +1090,6 @@ each_thread_cb(OchushaBBSThread *thread, gpointer user_data)
     {
       gdk_threads_enter();
 
-#if ENABLE_RENDERING_ON_IDLE
-      while (!try_get_rendering_right(args->application,
-				      args->info->threadlist_source_buffer,
-				      thread->board))
-	{
-	  gdk_threads_leave();
-	  ochusha_async_buffer_wait(args->info->threadlist_source_buffer,
-				    "bulletin_board_ui.c: each_thread_cb()");
-	  gdk_threads_enter();
-	}
-#endif
-
       threadlist_view_append_thread(view, thread,
 				    info->view_rank, args->number_of_threads);
       update_threadlist_entry_style(args->application, view, thread);
@@ -1646,6 +1631,7 @@ item_view_being_closed_cb(PanedNotebook *paned_notebook,
 	}
     }
 
+  info->res_num = 0;
   info->last_read = NULL;
   info->next_mark = NULL;
   if (info->scroller_id != 0)
