@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_ui.c,v 1.44 2003/12/12 21:43:52 fuyu Exp $
+ * $Id: ochusha_ui.c,v 1.46 2003/12/15 17:34:33 fuyu Exp $
  */
 
 #include "config.h"
@@ -985,13 +985,6 @@ write_optional_prefs(FILE *file, gpointer user_data)
   OUTPUT_CONFIG_ATTRIBUTE_INT(file, application, boardlist_width);
   OUTPUT_CONFIG_ATTRIBUTE_INT(file, application, threadlist_height);
 
-#if ENABLE_RENDERING_ON_IDLE
-  OUTPUT_CONFIG_ATTRIBUTE_INT(file, application, rendering_unit);
-  OUTPUT_CONFIG_ATTRIBUTE_INT(file, application,
-			      weight_of_threadlist_rendering);
-  OUTPUT_CONFIG_ATTRIBUTE_INT(file, application, weight_of_response_rendering);
-#endif
-
   OUTPUT_CONFIG_ATTRIBUTE_INT(file, application, boardlist_pane_style);
   OUTPUT_CONFIG_ATTRIBUTE_BOOLEAN(file, application, board_tab_shrinkable);
   OUTPUT_CONFIG_ATTRIBUTE_INT(file, application, board_tab_minimum_size);
@@ -1086,15 +1079,6 @@ configure_application(OchushaApplication *application)
       application->boardlist_width = OCHUSHA_DEFAULT_BOARDLIST_WIDTH;
       application->threadlist_height = OCHUSHA_DEFAULT_THREADLIST_HEIGHT;
 
-#if ENABLE_RENDERING_ON_IDLE
-      application->rendering_unit
-	= OCHUSHA_DEFAULT_RENDERING_UNIT;
-      application->weight_of_threadlist_rendering
-	= OCHUSHA_DEFAULT_WEIGHT_OF_THREADLIST_RENDERING;
-      application->weight_of_response_rendering
-	= OCHUSHA_DEFAULT_WEIGHT_OF_RESPONSE_RENDERING;
-#endif
-
       /* İϢ */
       application->boardlist_pane_style = HPANED_STYLE;
       application->board_tab_shrinkable = OCHUSHA_DEFAULT_BOARD_TAB_SHRINKABLE;
@@ -1157,18 +1141,6 @@ configure_application(OchushaApplication *application)
     application->threadlist_view_contents
       = G_STRDUP(OCHUSHA_DEFAULT_THREADLIST_VIEW_CONTENTS);
 
-#if ENABLE_RENDERING_ON_IDLE
-  if (application->rendering_unit < 0)
-    application->rendering_unit = 0;
-
-  if (application->weight_of_threadlist_rendering < 0)
-    application->weight_of_threadlist_rendering = 0;
-
-  if (application->weight_of_response_rendering < 0)
-    application->weight_of_response_rendering = 0;
-#endif
-
-
   if (application->board_tab_minimum_size == 0)
     application->board_tab_minimum_size
       = OCHUSHA_DEFAULT_BOARD_TAB_MINIMUM_SIZE;
@@ -1201,31 +1173,6 @@ read_optional_prefs(GHashTable *pref_attrs, gpointer user_data)
   application->threadlist_height
     = ochusha_utils_get_attribute_int(pref_attrs, "threadlist_height");
 
-#if ENABLE_RENDERING_ON_IDLE
-  if (g_hash_table_lookup(pref_attrs, "rendering_unit") != NULL)
-    application->rendering_unit
-      = ochusha_utils_get_attribute_int(pref_attrs, "rendering_unit");
-  else
-    application->rendering_unit = OCHUSHA_DEFAULT_RENDERING_UNIT;
-
-  if (g_hash_table_lookup(pref_attrs,
-			  "weight_of_threadlist_rendering") != NULL)
-    application->weight_of_threadlist_rendering
-      = ochusha_utils_get_attribute_int(pref_attrs,
-					"weight_of_threadlist_rendering");
-  else
-    application->weight_of_threadlist_rendering
-      = OCHUSHA_DEFAULT_WEIGHT_OF_THREADLIST_RENDERING;
-  
-  if (g_hash_table_lookup(pref_attrs, "weight_of_response_rendering") != NULL)
-    application->weight_of_response_rendering
-      = ochusha_utils_get_attribute_int(pref_attrs,
-					"weight_of_response_rendering");
-  else
-    application->weight_of_response_rendering
-      = OCHUSHA_DEFAULT_WEIGHT_OF_RESPONSE_RENDERING;
-#endif
-
   if (g_hash_table_lookup(pref_attrs, "boardlist_pane_style") != NULL)
     application->boardlist_pane_style
       = ochusha_utils_get_attribute_int(pref_attrs, "boardlist_pane_style");
@@ -2334,7 +2281,7 @@ open_debug_console(OchushaApplication *application)
     }
 
   dialog = gtk_dialog_new_with_buttons(_("Debug Outputs"),
-				       application->top_level,
+				       NULL,
 				       GTK_DIALOG_DESTROY_WITH_PARENT,
 				       GTK_STOCK_OK, GTK_RESPONSE_OK,
 				       NULL);
@@ -2561,144 +2508,3 @@ popup_open_url_dialog(OchushaApplication *application)
     initialize_open_url_dialog(application);
   gtk_widget_show_all(open_url_dialog);
 }
-
-
-#if ENABLE_RENDERING_ON_IDLE
-/*
- * ĤGDKΥƥ륻Ǽ롣
- */
-static gint current_rendering_load = 0;
-static GSList *rendered_buffers = NULL;
-static guint advance_rendering_on_idle_func_id = 0;
-
-
-static void
-wake_up_helper(OchushaAsyncBuffer *buffer, OchushaApplication *application)
-{
-  ochusha_async_buffer_broadcast(buffer, "ochusha_ui.c: wake_up_helper()");
-  g_object_unref(G_OBJECT(buffer));
-}
-
-
-/*
- * advance_rendering_on_idle:
- *
- * GLibΥᥤ롼פidleؿȤϿᥤ롼פˤˤʤä
- * ԤäƤ󥰥åɤ򵯤
- */
-static gboolean
-advance_rendering_on_idle(gpointer application)
-{
-  GSList *old_rendered_buffers;
-
-  gdk_threads_enter();
-
-  old_rendered_buffers = rendered_buffers;
-  rendered_buffers = NULL;
-  advance_rendering_on_idle_func_id = 0;
-  current_rendering_load = 0;
-
-  gdk_threads_leave();
-
-#if DEBUG_RENDERING_ON_IDLE
-  fprintf(stderr, "advance_rendering_on_idle()\n");
-#endif
-  /*
-   * 򵯤Τ̵̤ͥåȥξ֤
-   * ԤΥǡ̤ʤɺ٤򵤤ˤƤޤǸ̩˥åɿĴ
-   * ɬפϤʤȻפΤǡޤåɥå
-   * ƤåɤοȤΤ̵̤餯ʤΤ
-   * GUIΥ쥹ݥ󥹤˱ƶͿʤ
-   * ΤϥǤȤȤǡ
-   * application->maximum_number_of_renderingοåɤ򵯤
-   * Żʤåɤ̤Υåɤ򵯤Ȥץȥ
-   * Ȥˤ롣
-   */
-  g_slist_foreach(old_rendered_buffers, (GFunc)wake_up_helper, application);
-
-  return FALSE;
-}
-
-
-/*
- * try_get_rendering_right:
- *
- * item󥰤륹åɤߥ󥰤Ԥäɤɤ
- * Ƚꤹ롣ߥ󥰤ԤäƤ륹åɿ
- * application->maximum_number_of_rendering_threads̤ǤС
- * 󥰤ĤȤ̣TRUE֤ʳξˤFALSE֤
- * 󥰤ԤåɤϤδؿFALSE֤Ȥˤϥ
- * Ԥ鷺bufferwait롣TRUEåɤ1ñʬ󥰤
- * Ԥä顢return_rendering_semaphore()ˤꥻޥե֤
- *
- * gdk_threads_enter()ĶƤӽФȡ
- */
-gboolean
-try_get_rendering_right(OchushaApplication *application,
-			OchushaAsyncBuffer *buffer, gpointer item)
-{
-  gboolean result = FALSE;
-  PanedNotebook *contents_window
-    = PANED_NOTEBOOK(application->contents_window);
-  OchushaBulletinBoard *current_board
-    = (OchushaBulletinBoard *)paned_notebook_get_current_item(contents_window);
-
-#if DEBUG_RENDERING_ON_IDLE
-  fprintf(stderr, "try_get_rendering_semaphore(): buffer=%p, item=%p\n",
-	  buffer, item);
-#endif
-
-  if (current_board == NULL || application->rendering_unit == 0)
-    result = TRUE;
-  else
-    {
-      if (OCHUSHA_IS_BULLETIN_BOARD(item)
-	  && (current_board == item
-	      || current_rendering_load < application->rendering_unit))
-	result = TRUE;
-      else if (OCHUSHA_IS_BBS_THREAD(item))
-	{
-	  PanedNotebook *board_pane = (PanedNotebook *)paned_notebook_get_current_item_view(contents_window);
-	  if (board_pane == NULL)
-	    result = TRUE;
-	  else
-	    {
-	      OchushaBBSThread *current_thread
-		= (OchushaBBSThread *)paned_notebook_get_current_item(board_pane);
-	      if (current_thread == NULL || current_thread == item
-		  || current_rendering_load < application->rendering_unit)
-		result = TRUE;
-	    }
-	}
-    }
-
-  if (result)
-    {
-      if (OCHUSHA_IS_BULLETIN_BOARD(item))
-	current_rendering_load += application->weight_of_threadlist_rendering;
-      else if (OCHUSHA_IS_BBS_THREAD(item))
-	current_rendering_load += application->weight_of_response_rendering;
-#if DEBUG_RENDERING_ON_IDLE
-      else
-	fprintf(stderr, "Unknown item(%p) found\n", item);
-#endif
-    }
-  else
-    {
-      g_object_ref(G_OBJECT(buffer));
-      rendered_buffers = g_slist_append(rendered_buffers, buffer);
-
-      if (advance_rendering_on_idle_func_id == 0)
-	advance_rendering_on_idle_func_id
-	  = g_idle_add_full(G_PRIORITY_HIGH,
-			    advance_rendering_on_idle, application, NULL);
-    }
-
-#if DEBUG_RENDERING_ON_IDLE
-  fprintf(stderr, "  result=%d, current_rendering_load=%d\n",
-	  result, current_rendering_load);
-#endif
-
-  return result;
-}
-#endif
