@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_ui.h,v 1.28 2003/12/12 21:43:52 fuyu Exp $
+ * $Id: ochusha_ui.h,v 1.31 2003/12/15 17:34:34 fuyu Exp $
  */
 
 #ifndef _OCHUSHA_UI_H_
@@ -46,15 +46,11 @@
 #define DEBUG_GUI_MOST		0
 #define DEBUG_THREAD		0
 #define DEBUG_THREAD_MOST	0
-#define DEBUG_NETWORK		0
-#define DEBUG_NETWORK_MOST	0
 #define DEBUG_WIDGET		0
 #define DEBUG_WIDGET_MOST	0
-#define DEBUG_RENDERING_ON_IDLE	0
 
 #define ENABLE_DEBUG_CONSOLE						0
 #define ENABLE_MAIN_TOOLBAR						0
-#define ENABLE_RENDERING_ON_IDLE					0
 
 #define OCHUSHA_DEFAULT_WIDTH						600
 #define OCHUSHA_DEFAULT_HEIGHT						400
@@ -182,14 +178,6 @@ struct _OchushaApplication
   gint threadlist_height;
 
 
-#if ENABLE_RENDERING_ON_IDLE	/* ݤ */
-  /* åȤΥ٤Ĵ */
-  gint rendering_unit;
-  gint weight_of_threadlist_rendering;
-  gint weight_of_response_rendering;
-#endif
-
-
   /* paneɽˡʤ */
   gint boardlist_pane_style;
   gboolean board_tab_shrinkable;
@@ -298,13 +286,6 @@ void setup_for_tab_label_animation(OchushaAsyncBuffer *buffer,
 				   IconLabel *tab_label);
 GtkWidget *get_tab_label(const gchar *label_text);
 
-#if ENABLE_RENDERING_ON_IDLE
-gboolean try_get_rendering_right(OchushaApplication *application,
-				 OchushaAsyncBuffer *buffer,
-				 gpointer item);
-#endif
-
-
 #ifdef __cplusplus
 } // extern "C"
 #endif
