@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_board_2ch.c,v 1.22 2003/12/08 15:33:17 fuyu Exp $
+ * $Id: ochusha_board_2ch.c,v 1.23 2003/12/14 16:10:28 fuyu Exp $
  */
 
 #include "config.h"
@@ -477,6 +477,12 @@ ochusha_board_2ch_create_new_thread(OchushaBulletinBoard *board,
   else
     {
 #if DEBUG_POST
+      char message[4096];
+      snprintf(message, 4096, "board_2ch(%s)->date == NULL\n",
+	       board->name);
+      ochusha_network_broker_output_log(broker, message);
+#endif
+#if DEBUG_POST_MOST
       fprintf(stderr, "board_2ch->date == NULL!\n");
 #endif
       time = ochusha_utils_get_utc_time(board_2ch->last_modified);
@@ -532,7 +538,7 @@ ochusha_board_2ch_create_new_thread(OchushaBulletinBoard *board,
   return TRUE;
 
  error_exit:
-#if DEBUG_POST
+#if DEBUG_POST_MOST
   fprintf(stderr, "Error happen\n");
 #endif
 
