@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_config.c,v 1.13 2003/11/26 06:02:14 fuyu Exp $
+ * $Id: ochusha_config.c,v 1.14 2003/12/01 07:26:37 fuyu Exp $
  */
 
 #include "config.h"
@@ -566,17 +566,7 @@ endElementHandler(void *context, const xmlChar *name)
 	{
 	  sax_context->state = SAX_PREFERENCE_ATTRIBUTE;
 
-	  /* NOTE:
-	   * stringattributeƤSAXѡԹ()ǡĤ
-	   * ޤǤheapˤʤΤǤstrdup
-	   * SAXѡԹȤΤϡΥץŪˤ1ʸǤ٤
-	   * ƤSAXѡŪʣǤȤƸƤޤ礬ꡢ
-	   * Ϣ뤹뤿ΰХåեɬפǤ뤫顣
-	   */
-	  if (sax_context->current_attr_val != NULL)
-	    sax_context->current_attr_val
-	      = G_STRDUP(sax_context->current_attr_val);
-	  else
+	  if (sax_context->current_attr_val == NULL)
 	    sax_context->current_attr_val = G_STRDUP("");
 	  return;
 	}
@@ -612,7 +602,6 @@ endElementHandler(void *context, const xmlChar *name)
 }
 
 
-#define STRING_BUFFER_LENGTH	1024
 static void
 charactersHandler(void *context, const xmlChar *ch, int len)
 {
@@ -620,17 +609,15 @@ charactersHandler(void *context, const xmlChar *ch, int len)
 
   if (sax_context->state == SAX_PREFERENCE_ATTRIBUTE_STRING)
     {
-      static char buffer[STRING_BUFFER_LENGTH] = "";
-      int value_len;
       if (sax_context->current_attr_val == NULL)
-	buffer[0] = '\0';
-
-      value_len = strlen(buffer);
-      if (value_len + len >= STRING_BUFFER_LENGTH)
-	len = STRING_BUFFER_LENGTH - value_len - 1;
-
-      strncat(buffer, ch, len);
-      sax_context->current_attr_val = buffer;
+	sax_context->current_attr_val = G_STRNDUP(ch, len);
+      else
+	{
+	  int old_len = strlen(sax_context->current_attr_val);
+	  sax_context->current_attr_val
+	    = G_REALLOC(sax_context->current_attr_val, old_len + len + 1);
+	  strncat(sax_context->current_attr_val + old_len, ch, len);
+	}
     }
 }
 
