@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_network_broker.c,v 1.30 2003/12/11 18:04:19 fuyu Exp $
+ * $Id: ochusha_network_broker.c,v 1.35 2003/12/15 17:19:22 fuyu Exp $
  */
 
 #include "config.h"
@@ -61,6 +61,7 @@
 
 
 #define DISABLE_PERSISTENT_CONNECTION		0
+#define ENABLE_GZIPPED_TRANSFER			0
 #define ENABLE_GZIPPED_DIFFERENCIAL_READ	0
 
 #define CACHE_COMPARE_SIZE	128	/* Ĥѹǽˤ٤ */
@@ -70,16 +71,12 @@
 #define POLLING_INTERVAL_MILLIS	100
 
 
-#define DEBUG_NETWORK		0
-#define DEBUG_NETWORK_MOST	0
 #define DEBUG_MMAP		0
 
 
 static void ochusha_network_broker_class_init(OchushaNetworkBrokerClass *klass);
 static void ochusha_network_broker_init(OchushaNetworkBroker *broker);
 static void ochusha_network_broker_finalize(GObject *object);
-static void ochusha_network_broker_output_log(OchushaNetworkBroker *broker,
-					      const gchar *message);
 
 
 GType
@@ -245,7 +242,7 @@ ochusha_network_broker_new(OchushaConfig *config)
 }
 
 
-static void
+void
 ochusha_network_broker_output_log(OchushaNetworkBroker *broker,
 				  const gchar *message)
 {
@@ -382,7 +379,7 @@ write_buffer_to_cache(OchushaNetworkBroker *broker, const char *url,
 		   _("Couldn't update cache file for %s: %s (%d)\n"),
 		   url, strerror(errno), errno);
 	  ochusha_network_broker_output_log(broker, message);
-#if DEBUG_NETWORK
+#if DEBUG_NETWORK_MOST
 	  fprintf(stderr, "Couldn't update cache file for %s: %s (%d)\n",
 		  url, strerror(errno), errno);
 #endif
@@ -394,7 +391,7 @@ write_buffer_to_cache(OchushaNetworkBroker *broker, const char *url,
 	       _("Couldn't open cache file for %s: %s (%d)\n"),
 	       url, strerror(errno), errno);
       ochusha_network_broker_output_log(broker, message);
-#if DEBUG_NETWORK
+#if DEBUG_NETWORK_MOST
       fprintf(stderr, "Couldn't open cache file for %s: %s (%d)\n",
 	      url, strerror(errno), errno);
 #endif
@@ -478,7 +475,7 @@ get_content_encoding_type(ghttp_request *request)
     {
       if (strcmp(encoding, "gzip") == 0)
 	return GZIP_ENCODING;
-#if DEBUG_NETWORK
+#if DEBUG_NETWORK_MOST
       fprintf(stderr, "Content-Encoding: %s\n", encoding);
 #endif
       if (strcmp(encoding, "deflate") == 0)
@@ -664,7 +661,7 @@ static gboolean
 timeout_cb(WorkerSyncObject *sync_object)
 {
   gboolean finished;
-#if DEBUG_NETWORK
+#if DEBUG_NETWORK_MOST
   fprintf(stderr, "entering: timeout_cb(%p)\n", sync_object);
 #endif
   g_return_val_if_fail(OCHUSHA_IS_WORKER_SYNC_OBJECT(sync_object), FALSE);
@@ -678,7 +675,7 @@ timeout_cb(WorkerSyncObject *sync_object)
     }
   UNLOCK_WORKER_SYNC_OBJECT(sync_object);
 
-#if DEBUG_NETWORK
+#if DEBUG_NETWORK_MOST
   fprintf(stderr, "leaving: timeout_cb(%p)\n", sync_object);
 #endif
 
@@ -695,7 +692,7 @@ static gboolean
 poll_cb(GIOChannel *channel, GIOCondition condition,
 	WorkerSyncObject *sync_object)
 {
-#if DEBUG_NETWORK
+#if DEBUG_NETWORK_MOST
   fprintf(stderr, "entering: poll_cb(%p)\n", sync_object);
 #endif
   g_return_val_if_fail(OCHUSHA_IS_WORKER_SYNC_OBJECT(sync_object), FALSE);
@@ -712,7 +709,7 @@ poll_cb(GIOChannel *channel, GIOCondition condition,
   sync_object->poll_id = 0;
   UNLOCK_WORKER_SYNC_OBJECT(sync_object);
 
-#if DEBUG_NETWORK
+#if DEBUG_NETWORK_MOST
   fprintf(stderr, "leaving: poll_cb(%p)\n", sync_object);
 #endif
   g_object_unref(G_OBJECT(sync_object));
@@ -762,13 +759,16 @@ http_read_from_url(OchushaNetworkBroker *broker, OchushaAsyncBuffer *buffer)
   ContentEncodingType content_encoding = UNKNOWN_ENCODING;
   GzipBuffer *gzip_buffer = NULL;
   ghttp_status state = ghttp_not_done;
+  ghttp_current_status current_status;
 
   request = ghttp_request_new();
   args->request = request;	/* 塹Τˡġ */
 
   ghttp_set_uri(request, (char *)url);
   ghttp_set_type(request, ghttp_type_get);
+#if ENABLE_GZIPPED_TRANSFER
   ghttp_set_header(request, http_hdr_Accept_Encoding, "deflate, gzip");
+#endif
 
 #if DISABLE_PERSISTENT_CONNECTION
   ghttp_set_header(request, http_hdr_Connection, "close");
@@ -817,40 +817,52 @@ http_read_from_url(OchushaNetworkBroker *broker, OchushaAsyncBuffer *buffer)
   ghttp_set_sync(request, ghttp_async);
   ghttp_prepare(request);
 
+  current_status = ghttp_get_status(request);
+
   sock_fd = -1;
   while (TRUE)
     {
       int body_len;
       char *body;
-      ghttp_current_status current_status;
+      ghttp_proc prev_proc;
       gboolean read_ok;
 
+      prev_proc = current_status.proc;
+
       LOCK_WORKER_SYNC_OBJECT(sync_object);
       if (sync_object->interrupted)
 	{
-	  read_ok = FALSE;
 	  sync_object->interrupted = FALSE;
+	  UNLOCK_WORKER_SYNC_OBJECT(sync_object);
+	  read_ok = FALSE;
 	}
       else if ((read_ok = sync_object->read_ok)
 	       || (state == ghttp_not_done && sock_fd == -1))
 	{
-#if 0
-	  struct timeval before;
-	  struct timeval after;
-	  gettimeofday(&before, NULL);
-#endif
-	  state = ghttp_process(request);
 	  sync_object->read_ok = FALSE;
-#if 0
-	  gettimeofday(&after, NULL);
-	  fprintf(stderr, "ghttp_process() consumes %ld.%ld (sec).\n",
-		  (after.tv_sec - before.tv_sec),
-		  (after.tv_usec - before.tv_usec) * 100000);
-#endif
+	  UNLOCK_WORKER_SYNC_OBJECT(sync_object);
+	  state = ghttp_process(request);
+	  current_status = ghttp_get_status(request);
 	}
-      UNLOCK_WORKER_SYNC_OBJECT(sync_object);
+      else
+	UNLOCK_WORKER_SYNC_OBJECT(sync_object);
 
-      current_status = ghttp_get_status(request);
+#if DEBUG_NETWORK_MOST
+      if (state == ghttp_error)
+	{
+	  fprintf(stderr, "\n* ghttp_process() returns ghttp_error\n");
+	  fprintf(stderr, "sock_fd = %d\n", ghttp_get_socket(request));
+	  fprintf(stderr, "error: \"%s\"\n", ghttp_get_error(request));
+	  fprintf(stderr, "current_status.proc = %d\n", current_status.proc);
+	  fprintf(stderr, "current_status.bytes_read = %d\n", current_status.bytes_read);
+	  fprintf(stderr, "current_status.bytes_total = %d\n", current_status.bytes_total);
+	}
+      else
+	{
+	  fprintf(stderr, "prev_proc = %d\n", prev_proc);
+	  fprintf(stderr, "current_status.proc = %d\n", current_status.proc);
+	}
+#endif
 
       if (current_status.proc == ghttp_proc_response
 	  || (sock_fd > 0 && current_status.proc == ghttp_proc_none))
@@ -878,7 +890,7 @@ http_read_from_url(OchushaNetworkBroker *broker, OchushaAsyncBuffer *buffer)
 
 		  snprintf(message, LOG_MESSAGE_SIZE,
 			   _("Cache is fresh: %s\n"), url);
-		  ochusha_network_broker_output_log(args->broker, message);
+		  ochusha_network_broker_output_log(broker, message);
 
 		  return FALSE;
 		}
@@ -888,11 +900,25 @@ http_read_from_url(OchushaNetworkBroker *broker, OchushaAsyncBuffer *buffer)
 
       if (state == ghttp_not_done)
 	{
+#if 1
+	  if (prev_proc == ghttp_proc_response_hdrs)
+	    read_ok = FALSE;
+#else
+	  const char *tmp_header;
+	  if (prev_proc == ghttp_proc_response_hdrs
+	      && (tmp_header = ghttp_get_header(request,
+						http_hdr_Transfer_Encoding))
+	      && strcasecmp(tmp_header, "chunked") == 0)
+	    read_ok = FALSE;
+#endif
 	  if (read_ok)
 	    ghttp_flush_response_buffer(request);
 	}
       else if (state == ghttp_error)
 	{
+#if DEBUG_NETWORK_MOST
+	  fprintf(stderr, "ghttp_process() returns ghttp_error.\n");
+#endif
 	  error_message = _("Unknown I/O error.");
 	  goto error_exit;
 	}
@@ -976,7 +1002,7 @@ http_read_from_url(OchushaNetworkBroker *broker, OchushaAsyncBuffer *buffer)
 			       _("Requested file seems to contain garbage: %s\n"),
 			       url);
 		      ochusha_network_broker_output_log(broker, message);
-#if DEBUG_NETWORK
+#if DEBUG_NETWORK_MOST
 		      fprintf(stderr, "Requested file seems to contain garbage: %s\n", url);
 #endif
 		    }
@@ -1063,7 +1089,7 @@ http_read_from_url(OchushaNetworkBroker *broker, OchushaAsyncBuffer *buffer)
 
   if (gzip_buffer != NULL)
     {
-#if DEBUG_NETWORK
+#if DEBUG_NETWORK_MOST
       fprintf(stderr, "What's happen?  Connection was closed but inflation hasn't been completed.\n");
 #endif
       gzip_buffer_free(gzip_buffer);
@@ -1125,6 +1151,23 @@ http_read_from_url(OchushaNetworkBroker *broker, OchushaAsyncBuffer *buffer)
 #if DEBUG_NETWORK_MOST
       fprintf(stderr, "access failed: status_code=%d %s\n",
 	      status_code, error_message);
+#endif
+#if DEBUG_NETWORK
+      {
+	int i;
+	char **headers = NULL;
+	int num_headers = 0;
+	ghttp_get_header_names(request, &headers, &num_headers);
+	for (i = 0; i < num_headers; i++)
+	  {
+	    snprintf(message, LOG_MESSAGE_SIZE, "%s: %s\n",
+		     headers[i], ghttp_get_header(request, headers[i]));
+	    ochusha_network_broker_output_log(broker, message);
+	    free(headers[i]);
+	  }
+	if (headers != NULL)
+	  free(headers);
+      }
 #endif
     }
   else if (status_code != 0)
@@ -1139,6 +1182,23 @@ http_read_from_url(OchushaNetworkBroker *broker, OchushaAsyncBuffer *buffer)
 		    message,
 		    &signal_result);
       ochusha_network_broker_output_log(broker, message);
+#if DEBUG_NETWORK
+      {
+	int i;
+	char **headers = NULL;
+	int num_headers = 0;
+	ghttp_get_header_names(request, &headers, &num_headers);
+	for (i = 0; i < num_headers; i++)
+	  {
+	    snprintf(message, LOG_MESSAGE_SIZE, "%s: %s\n",
+		     headers[i], ghttp_get_header(request, headers[i]));
+	    ochusha_network_broker_output_log(broker, message);
+	    free(headers[i]);
+	  }
+	if (headers != NULL)
+	  free(headers);
+      }
+#endif
 #if DEBUG_NETWORK_MOST
       fprintf(stderr, "%s\n", message);
 #endif
@@ -1194,7 +1254,7 @@ destruct_job_args(NetworkBrokerJobArgs *job_args)
 static void
 wakeup_now_cb(OchushaAsyncBuffer *buffer, WorkerSyncObject *sync_object)
 {
-#if DEBUG_NETWORK
+#if DEBUG_NETWORK_MOST
   fprintf(stderr, "entering: wakeup_now_cb\n");
 #endif
 
@@ -1207,7 +1267,7 @@ wakeup_now_cb(OchushaAsyncBuffer *buffer, WorkerSyncObject *sync_object)
     }
   UNLOCK_WORKER_SYNC_OBJECT(sync_object);
 
-#if DEBUG_NETWORK
+#if DEBUG_NETWORK_MOST
   fprintf(stderr, "leaving: wakeup_now_cb\n");
 #endif
 }
@@ -1218,7 +1278,7 @@ ochusha_network_broker_worker_sync_object_free(WorkerSyncObject *sync_object)
 {
   g_return_if_fail(OCHUSHA_IS_WORKER_SYNC_OBJECT(sync_object));
 
-#if DEBUG_NETWORK
+#if DEBUG_NETWORK_MOST
   fprintf(stderr, "entering: sync_object_free(%p)\n", sync_object);
 #endif
 
@@ -1286,6 +1346,7 @@ try_update_cache(WorkerThread *employee, OchushaAsyncBuffer *buffer)
   gboolean signal_result;
   NetworkBrokerJobArgs *args = g_object_get_qdata(G_OBJECT(buffer),
 						  broker_job_args_id);
+  OchushaNetworkBroker *broker = args->broker;
   WorkerSyncObject *sync_object = g_object_get_qdata(G_OBJECT(buffer),
 						     worker_sync_object_id);
   OchushaNetworkBrokerBufferStatus *status
@@ -1301,14 +1362,14 @@ try_update_cache(WorkerThread *employee, OchushaAsyncBuffer *buffer)
   if (!ochusha_async_buffer_active_ref(buffer,
 			"ochusha_network_broker.c: try_update_cache()"))
     {
-      g_signal_emit(G_OBJECT(args->broker),
+      g_signal_emit(G_OBJECT(broker),
 		    broker_signals[ACCESS_TERMINATED_SIGNAL],
 		    0,
 		    buffer,
 		    &signal_result);
 
       status->state = OCHUSHA_NETWORK_BROKER_BUFFER_STATE_ACCESS_FAILED;
-      g_signal_emit(G_OBJECT(args->broker),
+      g_signal_emit(G_OBJECT(broker),
 		    broker_signals[ACCESS_FAILED_SIGNAL],
 		    0,
 		    buffer,
@@ -1323,7 +1384,7 @@ try_update_cache(WorkerThread *employee, OchushaAsyncBuffer *buffer)
 
       snprintf(message, LOG_MESSAGE_SIZE,
 	       _("Access terminated: %s\n"), url);
-      ochusha_network_broker_output_log(args->broker, message);
+      ochusha_network_broker_output_log(broker, message);
 
       LOCK_WORKER_SYNC_OBJECT(sync_object);
       sync_object->finished = TRUE;
@@ -1332,7 +1393,7 @@ try_update_cache(WorkerThread *employee, OchushaAsyncBuffer *buffer)
       return;
     }
 
-  len = read_cache_to_buffer(args->broker->config, url, buffer);
+  len = read_cache_to_buffer(broker->config, url, buffer);
 
   if (len > 0)
     {	/* å夢ξ */
@@ -1370,10 +1431,12 @@ try_update_cache(WorkerThread *employee, OchushaAsyncBuffer *buffer)
       ghttp_set_type(request, ghttp_type_get);
       ghttp_set_header(request, http_hdr_Connection, "close");
 
-#if ENABLE_GZIPPED_DIFFERENCIAL_READ
+#if ENABLE_GZIPPED_TRANSFER
+# if ENABLE_GZIPPED_DIFFERENCIAL_READ
       ghttp_set_header(request, http_hdr_Accept_Encoding, "deflate, gzip");
-#else
+# else
       ghttp_set_header(request, http_hdr_Accept_Encoding, "deflate");
+# endif
 #endif
       ghttp_set_header(request, http_hdr_Range, header);
 
@@ -1385,11 +1448,11 @@ try_update_cache(WorkerThread *employee, OchushaAsyncBuffer *buffer)
 	  fprintf(stderr, "If-Modified-Since: %s\n", args->if_modified_since);
 #endif
 	}
-      if (!setup_common_request_headers(args->broker, request, FALSE))
+      if (!setup_common_request_headers(broker, request, FALSE))
 	{
 	  /* ۤäƥåϤɤΤ */
 	  status->state = OCHUSHA_NETWORK_BROKER_BUFFER_STATE_CACHE_IS_OK;
-	  g_signal_emit(G_OBJECT(args->broker),
+	  g_signal_emit(G_OBJECT(broker),
 			broker_signals[ACCESS_FAILED_SIGNAL],
 			0,
 			buffer,
@@ -1403,12 +1466,16 @@ try_update_cache(WorkerThread *employee, OchushaAsyncBuffer *buffer)
 	  goto finish_try_update_cache;
 	}
 
-      g_signal_emit(G_OBJECT(args->broker),
+      g_signal_emit(G_OBJECT(broker),
 		    broker_signals[ACCESS_STARTED_SIGNAL],
 		    0,
 		    buffer,
 		    &signal_result);
 
+      snprintf(message, LOG_MESSAGE_SIZE, _("Updating cache file: %s\n"),
+	       url);
+      ochusha_network_broker_output_log(broker, message);
+
       ghttp_set_sync(request, ghttp_async);
       ghttp_prepare(request);
 
@@ -1418,13 +1485,13 @@ try_update_cache(WorkerThread *employee, OchushaAsyncBuffer *buffer)
       if (!ochusha_async_buffer_update_length(buffer, offset,
 			"ochusha_network_broker.c: try_update_cache()"))
 	{
-	  g_signal_emit(G_OBJECT(args->broker),
+	  g_signal_emit(G_OBJECT(broker),
 			broker_signals[ACCESS_TERMINATED_SIGNAL],
 			0,
 			buffer,
 			&signal_result);
 	  status->state = OCHUSHA_NETWORK_BROKER_BUFFER_STATE_CACHE_IS_OK;
-	  g_signal_emit(G_OBJECT(args->broker),
+	  g_signal_emit(G_OBJECT(broker),
 			broker_signals[ACCESS_FAILED_SIGNAL],
 			0,
 			buffer,
@@ -1436,7 +1503,7 @@ try_update_cache(WorkerThread *employee, OchushaAsyncBuffer *buffer)
 
 	  snprintf(message, LOG_MESSAGE_SIZE,
 		   _("Access terminated: %s\n"), url);
-	  ochusha_network_broker_output_log(args->broker, message);
+	  ochusha_network_broker_output_log(broker, message);
 
 	  goto finish_try_update_cache;
 	}
@@ -1452,27 +1519,19 @@ try_update_cache(WorkerThread *employee, OchushaAsyncBuffer *buffer)
 	  LOCK_WORKER_SYNC_OBJECT(sync_object);
 	  if (sync_object->interrupted)
 	    {
-	      read_ok = FALSE;
 	      sync_object->interrupted = FALSE;
+	      UNLOCK_WORKER_SYNC_OBJECT(sync_object);
+	      read_ok = FALSE;
 	    }
 	  else if ((read_ok = sync_object->read_ok)
 		   || (state == ghttp_not_done && sock_fd == -1))
 	    {
-#if 0
-	      struct timeval before;
-	      struct timeval after;
-	      gettimeofday(&before, NULL);
-#endif
-	      state = ghttp_process(request);
 	      sync_object->read_ok = FALSE;
-#if 0
-	      gettimeofday(&after, NULL);
-	      fprintf(stderr, "ghttp_process() consumes %ld.%ld (sec).\n",
-		      (after.tv_sec - before.tv_sec),
-		      (after.tv_usec - before.tv_usec) * 100000);
-#endif
+	      UNLOCK_WORKER_SYNC_OBJECT(sync_object);
+	      state = ghttp_process(request);
 	    }
-	  UNLOCK_WORKER_SYNC_OBJECT(sync_object);
+	  else
+	    UNLOCK_WORKER_SYNC_OBJECT(sync_object);
 
 	  current_status = ghttp_get_status(request);
 
@@ -1497,7 +1556,7 @@ try_update_cache(WorkerThread *employee, OchushaAsyncBuffer *buffer)
 		  status->status_code = status_code;
 		  status->state
 		    = OCHUSHA_NETWORK_BROKER_BUFFER_STATE_CACHE_IS_OK;
-		  g_signal_emit(G_OBJECT(args->broker),
+		  g_signal_emit(G_OBJECT(broker),
 				broker_signals[ACCESS_COMPLETED_SIGNAL],
 				0,
 				buffer,
@@ -1507,7 +1566,7 @@ try_update_cache(WorkerThread *employee, OchushaAsyncBuffer *buffer)
 
 		  snprintf(message, LOG_MESSAGE_SIZE,
 			   _("Cache is fresh: %s\n"), url);
-		  ochusha_network_broker_output_log(args->broker, message);
+		  ochusha_network_broker_output_log(broker, message);
 
 		  goto finish_try_update_cache;
 		}
@@ -1572,7 +1631,7 @@ try_update_cache(WorkerThread *employee, OchushaAsyncBuffer *buffer)
 	  if (body_len > 0)
 	    {
 	      if (current_status.bytes_total > 0)
-		g_signal_emit(G_OBJECT(args->broker),
+		g_signal_emit(G_OBJECT(broker),
 			      broker_signals[ACCESS_PROGRESSED_SIGNAL],
 			      0,
 			      buffer,
@@ -1595,7 +1654,7 @@ try_update_cache(WorkerThread *employee, OchushaAsyncBuffer *buffer)
 		    {
 		      gzip_buffer_free(gzip_buffer);
 		      gzip_buffer = NULL;
-#if DEBUG_NETWORK
+#if DEBUG_NETWORK_MOST
 		      if (state != ghttp_done)
 			fprintf(stderr, "Requested file contains garbage?\n");
 #endif
@@ -1606,7 +1665,7 @@ try_update_cache(WorkerThread *employee, OchushaAsyncBuffer *buffer)
 							 body_len,
 			      "ochusha_network_broker.c: try_update_cache()"))
 		{	/* content_encoding == IDENTITY_ENCODING */
-		  g_signal_emit(G_OBJECT(args->broker),
+		  g_signal_emit(G_OBJECT(broker),
 				broker_signals[ACCESS_TERMINATED_SIGNAL],
 				0,
 				buffer,
@@ -1614,7 +1673,7 @@ try_update_cache(WorkerThread *employee, OchushaAsyncBuffer *buffer)
 
 		  status->state
 		    = OCHUSHA_NETWORK_BROKER_BUFFER_STATE_CACHE_IS_OK;
-		  g_signal_emit(G_OBJECT(args->broker),
+		  g_signal_emit(G_OBJECT(broker),
 				broker_signals[ACCESS_FAILED_SIGNAL],
 				0,
 				buffer,
@@ -1627,7 +1686,7 @@ try_update_cache(WorkerThread *employee, OchushaAsyncBuffer *buffer)
 
 		  snprintf(message, LOG_MESSAGE_SIZE,
 			   _("Access terminated: %s\n"), url);
-		  ochusha_network_broker_output_log(args->broker, message);
+		  ochusha_network_broker_output_log(broker, message);
 
 		  goto finish_try_update_cache;
 		}
@@ -1656,7 +1715,7 @@ try_update_cache(WorkerThread *employee, OchushaAsyncBuffer *buffer)
 	      if (!ochusha_async_buffer_signal(buffer,
 			"ochusha_network_broker.c: try_update_cache()"))
 		{
-		  g_signal_emit(G_OBJECT(args->broker),
+		  g_signal_emit(G_OBJECT(broker),
 				broker_signals[ACCESS_TERMINATED_SIGNAL],
 				0,
 				buffer,
@@ -1664,7 +1723,7 @@ try_update_cache(WorkerThread *employee, OchushaAsyncBuffer *buffer)
 
 		  status->state
 		    = OCHUSHA_NETWORK_BROKER_BUFFER_STATE_CACHE_IS_OK;
-		  g_signal_emit(G_OBJECT(args->broker),
+		  g_signal_emit(G_OBJECT(broker),
 				broker_signals[ACCESS_FAILED_SIGNAL],
 				0,
 				buffer,
@@ -1678,7 +1737,7 @@ try_update_cache(WorkerThread *employee, OchushaAsyncBuffer *buffer)
 		  snprintf(message, LOG_MESSAGE_SIZE,
 			   _("Access terminated: %s\n"),
 			   url);
-		  ochusha_network_broker_output_log(args->broker, message);
+		  ochusha_network_broker_output_log(broker, message);
 
 		  goto finish_try_update_cache;
 		}
@@ -1721,17 +1780,17 @@ try_update_cache(WorkerThread *employee, OchushaAsyncBuffer *buffer)
 	status->date = NULL;
 
       status->status_code = status_code;
-      g_signal_emit(G_OBJECT(args->broker),
+      g_signal_emit(G_OBJECT(broker),
 		    broker_signals[ACCESS_COMPLETED_SIGNAL],
 		    0,
 		    buffer,
 		    &signal_result);
       ghttp_request_destroy(request);
       args->request = NULL;
-      write_buffer_to_cache(args->broker, url, buffer);
+      write_buffer_to_cache(broker, url, buffer);
 
       snprintf(message, LOG_MESSAGE_SIZE, _("Cache updated: %s\n"), url);
-      ochusha_network_broker_output_log(args->broker, message);
+      ochusha_network_broker_output_log(broker, message);
 
       goto finish_try_update_cache;
 
@@ -1745,19 +1804,19 @@ try_update_cache(WorkerThread *employee, OchushaAsyncBuffer *buffer)
 
       snprintf(message, LOG_MESSAGE_SIZE,
 	       _("Cache is dirty: %s\n"), url);
-      ochusha_network_broker_output_log(args->broker, message);
+      ochusha_network_broker_output_log(broker, message);
 
       if (!ochusha_async_buffer_update_length(buffer, 0,
 			"ochusha_network_broker.c: try_update_cache()"))
 	{
-	  g_signal_emit(G_OBJECT(args->broker),
+	  g_signal_emit(G_OBJECT(broker),
 			broker_signals[ACCESS_TERMINATED_SIGNAL],
 			0,
 			buffer,
 			&signal_result);
 	  status->state = OCHUSHA_NETWORK_BROKER_BUFFER_STATE_ACCESS_FAILED;
 
-	  g_signal_emit(G_OBJECT(args->broker),
+	  g_signal_emit(G_OBJECT(broker),
 		broker_signals[ACCESS_FAILED_SIGNAL],
 		0,
 		buffer,
@@ -1767,7 +1826,7 @@ try_update_cache(WorkerThread *employee, OchushaAsyncBuffer *buffer)
 
 	  snprintf(message, LOG_MESSAGE_SIZE,
 		   _("Access terminated: %s\n"), url);
-	  ochusha_network_broker_output_log(args->broker, message);
+	  ochusha_network_broker_output_log(broker, message);
 
 	  goto finish_try_update_cache;
 	}
@@ -1779,13 +1838,13 @@ try_update_cache(WorkerThread *employee, OchushaAsyncBuffer *buffer)
     }
 
   /* å夬ʤääƤ */
-  if (http_read_from_url(args->broker, buffer))
+  if (http_read_from_url(broker, buffer))
     {
       /* ̿ */
       if (status->state == OCHUSHA_NETWORK_BROKER_BUFFER_STATE_DIRECT_ACCESS)
 	status->state = OCHUSHA_NETWORK_BROKER_BUFFER_STATE_ACCESS_OK;
 
-      write_buffer_to_cache(args->broker, url, buffer);
+      write_buffer_to_cache(broker, url, buffer);
     }
   ochusha_async_buffer_fix(buffer,
 			   "ochusha_network_broker.c: try_update_cache");
@@ -1800,14 +1859,14 @@ try_update_cache(WorkerThread *employee, OchushaAsyncBuffer *buffer)
     {
       snprintf(message, LOG_MESSAGE_SIZE,
 	       _("Access failed(%s): %s\n"), url, error_message);
-      g_signal_emit(G_OBJECT(args->broker),
+      g_signal_emit(G_OBJECT(broker),
 		    broker_signals[ACCESS_FAILED_SIGNAL],
 		    0,
 		    buffer,
 		    OCHUSHA_NETWORK_BROKER_FAILURE_REASON_UNKNOWN,
 		    error_message,
 		    &signal_result);
-      ochusha_network_broker_output_log(args->broker, message);
+      ochusha_network_broker_output_log(broker, message);
     }
   else
     {
@@ -1816,29 +1875,46 @@ try_update_cache(WorkerThread *employee, OchushaAsyncBuffer *buffer)
 	{
 	  snprintf(message, LOG_MESSAGE_SIZE, _("Access failed(%s): %d (%s)"),
 		   url, status_code, ghttp_reason_phrase(request));
-	  g_signal_emit(G_OBJECT(args->broker),
+	  g_signal_emit(G_OBJECT(broker),
 			broker_signals[ACCESS_FAILED_SIGNAL],
 			0,
 			buffer,
 			OCHUSHA_NETWORK_BROKER_FAILURE_REASON_UNKNOWN,
 			message,
 			&signal_result);
-	  ochusha_network_broker_output_log(args->broker, message);
+	  ochusha_network_broker_output_log(broker, message);
 	}
       else
 	{
 	  snprintf(message, LOG_MESSAGE_SIZE,
 		   _("Access failed(%s): unknown reason.\n"),
 		   url);
-	  g_signal_emit(G_OBJECT(args->broker),
+	  g_signal_emit(G_OBJECT(broker),
 			broker_signals[ACCESS_FAILED_SIGNAL],
 			0,
 			buffer,
 			OCHUSHA_NETWORK_BROKER_FAILURE_REASON_UNKNOWN,
 			message,
 			&signal_result);
-	  ochusha_network_broker_output_log(args->broker, message);
+	  ochusha_network_broker_output_log(broker, message);
 	}
+#if DEBUG_NETWORK
+      {
+	int i;
+	char **headers = NULL;
+	int num_headers = 0;
+	ghttp_get_header_names(request, &headers, &num_headers);
+	for (i = 0; i < num_headers; i++)
+	  {
+	    snprintf(message, LOG_MESSAGE_SIZE, "%s: %s\n",
+		     headers[i], ghttp_get_header(request, headers[i]));
+	    ochusha_network_broker_output_log(broker, message);
+	    free(headers[i]);
+	  }
+	if (headers != NULL)
+	  free(headers);
+      }
+#endif
     }
 
   if (request != NULL)
@@ -1865,6 +1941,7 @@ refresh_cache_after_read(WorkerThread *employee, OchushaAsyncBuffer *buffer)
   gboolean signal_result;
   NetworkBrokerJobArgs *args = g_object_get_qdata(G_OBJECT(buffer),
 					      broker_job_args_id);
+  OchushaNetworkBroker *broker = args->broker;
   OchushaNetworkBrokerBufferStatus *status
     = g_object_get_qdata(G_OBJECT(buffer), broker_buffer_status_id);
   gchar message[LOG_MESSAGE_SIZE];
@@ -1877,7 +1954,7 @@ refresh_cache_after_read(WorkerThread *employee, OchushaAsyncBuffer *buffer)
 		"ochusha_network_broker.c: refresh_cache_after_read()"))
     {
       status->state = OCHUSHA_NETWORK_BROKER_BUFFER_STATE_ACCESS_FAILED;
-      g_signal_emit(G_OBJECT(args->broker),
+      g_signal_emit(G_OBJECT(broker),
 		    broker_signals[ACCESS_TERMINATED_SIGNAL],
 		    0,
 		    buffer,
@@ -1887,24 +1964,24 @@ refresh_cache_after_read(WorkerThread *employee, OchushaAsyncBuffer *buffer)
 
   status->state = OCHUSHA_NETWORK_BROKER_BUFFER_STATE_DIRECT_ACCESS;
 
-  if (http_read_from_url(args->broker, buffer))
+  if (http_read_from_url(broker, buffer))
     {
       /* ̿ */
       status->state = OCHUSHA_NETWORK_BROKER_BUFFER_STATE_ACCESS_OK;
       /* ХåեƤ򥭥å˽񤭹ࡣ*/
-      write_buffer_to_cache(args->broker, args->url, buffer);
+      write_buffer_to_cache(broker, args->url, buffer);
     }
   else
     {
       /* ̿Ԥå夬(if_modified_sinceNULL)ʾ */
-      if (read_cache_to_buffer(args->broker->config, args->url, buffer))
+      if (read_cache_to_buffer(broker->config, args->url, buffer))
 	{
 	  status->state = OCHUSHA_NETWORK_BROKER_BUFFER_STATE_CACHE_HIT;
 	  if (status->status_code == 304)
 	    {	/* å夬ä */
 	      if (args->if_modified_since != NULL)
 		status->last_modified = G_STRDUP(args->if_modified_since);
-	      g_signal_emit(G_OBJECT(args->broker),
+	      g_signal_emit(G_OBJECT(broker),
 			    broker_signals[ACCESS_COMPLETED_SIGNAL],
 			    0,
 			    buffer,
@@ -1912,7 +1989,7 @@ refresh_cache_after_read(WorkerThread *employee, OchushaAsyncBuffer *buffer)
 	    }
 	  else
 	    {	/* ̿˼ԤΤǻʤåȤ */
-	      g_signal_emit(G_OBJECT(args->broker),
+	      g_signal_emit(G_OBJECT(broker),
 			    broker_signals[ACCESS_FAILED_SIGNAL],
 			    0,
 			    buffer,
@@ -1922,7 +1999,7 @@ refresh_cache_after_read(WorkerThread *employee, OchushaAsyncBuffer *buffer)
 	      snprintf(message, LOG_MESSAGE_SIZE,
 		       _("Use cached file(%s): due to networking error.\n"),
 		       args->url);
-	      ochusha_network_broker_output_log(args->broker, message);
+	      ochusha_network_broker_output_log(broker, message);
 	    }
 	}
       else
@@ -1930,7 +2007,7 @@ refresh_cache_after_read(WorkerThread *employee, OchushaAsyncBuffer *buffer)
 	  if (status->status_code == 304)
 	    {
 	      /* ٤å夬Ĥʤ */
-	      g_signal_emit(G_OBJECT(args->broker),
+	      g_signal_emit(G_OBJECT(broker),
 			broker_signals[ACCESS_FAILED_SIGNAL],
 			0,
 			buffer,
@@ -1940,13 +2017,13 @@ refresh_cache_after_read(WorkerThread *employee, OchushaAsyncBuffer *buffer)
 	      snprintf(message, LOG_MESSAGE_SIZE,
 		       _("Couldn't find cache file: %s\n"),
 		       args->url);
-	      ochusha_network_broker_output_log(args->broker, message);
+	      ochusha_network_broker_output_log(broker, message);
 	    }
 	  else
 	    {
 	      /* ̤˼ */
 	      if (buffer->state != OCHUSHA_ASYNC_BUFFER_TERMINATED)
-		g_signal_emit(G_OBJECT(args->broker),
+		g_signal_emit(G_OBJECT(broker),
 			      broker_signals[ACCESS_FAILED_SIGNAL],
 			      0,
 			      buffer,
@@ -1954,7 +2031,7 @@ refresh_cache_after_read(WorkerThread *employee, OchushaAsyncBuffer *buffer)
 			      _("Couldn't read data via the network."),
 			      &signal_result);
 	      else
-		g_signal_emit(G_OBJECT(args->broker),
+		g_signal_emit(G_OBJECT(broker),
 			      broker_signals[ACCESS_TERMINATED_SIGNAL],
 			      0,
 			      buffer,
@@ -1980,6 +2057,7 @@ force_read(WorkerThread *employee, OchushaAsyncBuffer *buffer)
   gboolean signal_result;
   NetworkBrokerJobArgs *args = g_object_get_qdata(G_OBJECT(buffer),
 					      broker_job_args_id);
+  OchushaNetworkBroker *broker = args->broker;
   OchushaNetworkBrokerBufferStatus *status
     = g_object_get_qdata(G_OBJECT(buffer), broker_buffer_status_id);
 
@@ -1991,7 +2069,7 @@ force_read(WorkerThread *employee, OchushaAsyncBuffer *buffer)
 				"ochusha_network_broker.c: force_read()"))
     {
       status->state = OCHUSHA_NETWORK_BROKER_BUFFER_STATE_ACCESS_FAILED;
-      g_signal_emit(G_OBJECT(args->broker),
+      g_signal_emit(G_OBJECT(broker),
 		    broker_signals[ACCESS_TERMINATED_SIGNAL],
 		    0,
 		    buffer,
@@ -2007,7 +2085,7 @@ force_read(WorkerThread *employee, OchushaAsyncBuffer *buffer)
       args->if_modified_since = NULL;
     }
 
-  if (http_read_from_url(args->broker, buffer))
+  if (http_read_from_url(broker, buffer))
     {
       /* ̿ */
       status->state = OCHUSHA_NETWORK_BROKER_BUFFER_STATE_ACCESS_OK;
@@ -2019,7 +2097,7 @@ force_read(WorkerThread *employee, OchushaAsyncBuffer *buffer)
     {
       /* ̿ */
       status->state = OCHUSHA_NETWORK_BROKER_BUFFER_STATE_ACCESS_FAILED;
-#if DEBUG_NETWORK
+#if DEBUG_NETWORK_MOST
       fprintf(stderr, "reading from %s failed.\n", args->url);
 #endif
     }
@@ -2192,7 +2270,9 @@ http_read_from_url_synchronously(OchushaNetworkBroker *broker,
 
   ghttp_set_uri(request, (char *)url);
   ghttp_set_type(request, ghttp_type_get);
+#if ENABLE_GZIPPED_TRANSFER
   ghttp_set_header(request, http_hdr_Accept_Encoding, "deflate, gzip");
+#endif
   ghttp_set_header(request, http_hdr_Connection, "close");
 
   if (!setup_common_request_headers(broker, request, FALSE))
@@ -2242,7 +2322,7 @@ http_read_from_url_synchronously(OchushaNetworkBroker *broker,
 	status->date = G_STRDUP(tmp_header);
       else
 	status->date = NULL;
-#if DEBUG_NETWORK
+#if DEBUG_NETWORK_MOST
       fprintf(stderr, "Synchronous read done.\n");
 #endif
     }
@@ -2312,7 +2392,7 @@ http_read_from_url_synchronously(OchushaNetworkBroker *broker,
 	    {
 	      gzip_buffer_free(gzip_buffer);
 	      gzip_buffer = NULL;
-#if DEBUG_NETWORK
+#if DEBUG_NETWORK_MOST
 	      if (state != ghttp_done)
 		fprintf(stderr, "Requested file contains garbage?\n");
 #endif
@@ -2338,7 +2418,7 @@ http_read_from_url_synchronously(OchushaNetworkBroker *broker,
 
   if (gzip_buffer != NULL)
     {
-#if DEBUG_NETWORK
+#if DEBUG_NETWORK_MOST
       fprintf(stderr, "What's happen?  Connection was closed but inflation hasn't been completed.\n");
 #endif
       gzip_buffer_free(gzip_buffer);
@@ -2356,7 +2436,7 @@ http_read_from_url_synchronously(OchushaNetworkBroker *broker,
   return TRUE;
 
  error_exit:
-#if DEBUG_NETWORK
+#if DEBUG_NETWORK_MOST
   fprintf(stderr, "force_read_synchronously(): error.\n");
 #endif
   if (error_message != NULL)
@@ -2408,6 +2488,7 @@ force_read_synchronously(WorkerThread *employee, OchushaAsyncBuffer *buffer)
   gboolean signal_result;
   NetworkBrokerJobArgs *args = g_object_get_qdata(G_OBJECT(buffer),
 					      broker_job_args_id);
+  OchushaNetworkBroker *broker = args->broker;
   OchushaNetworkBrokerBufferStatus *status
     = g_object_get_qdata(G_OBJECT(buffer), broker_buffer_status_id);
 
@@ -2419,7 +2500,7 @@ force_read_synchronously(WorkerThread *employee, OchushaAsyncBuffer *buffer)
 		"ochusha_network_broker.c: force_read_synchronously()"))
     {
       status->state = OCHUSHA_NETWORK_BROKER_BUFFER_STATE_ACCESS_FAILED;
-      g_signal_emit(G_OBJECT(args->broker),
+      g_signal_emit(G_OBJECT(broker),
 		    broker_signals[ACCESS_TERMINATED_SIGNAL],
 		    0,
 		    buffer,
@@ -2435,7 +2516,7 @@ force_read_synchronously(WorkerThread *employee, OchushaAsyncBuffer *buffer)
       args->if_modified_since = NULL;
     }
 
-  if (http_read_from_url_synchronously(args->broker, buffer))
+  if (http_read_from_url_synchronously(broker, buffer))
     {
       /* ̿ */
       status->state = OCHUSHA_NETWORK_BROKER_BUFFER_STATE_ACCESS_OK;
@@ -2447,7 +2528,7 @@ force_read_synchronously(WorkerThread *employee, OchushaAsyncBuffer *buffer)
     {
       /* ̿ */
       status->state = OCHUSHA_NETWORK_BROKER_BUFFER_STATE_ACCESS_FAILED;
-#if DEBUG_NETWORK
+#if DEBUG_NETWORK_MOST
       fprintf(stderr, "reading from %s failed.\n", args->url);
 #endif
     }
@@ -2564,6 +2645,9 @@ ochusha_network_broker_try_post(OchushaNetworkBroker *broker,
 				OchushaNetworkBrokerPostStatus *status)
 {
   ghttp_request *request = ghttp_request_new();
+#if DEBUG_NETWORK
+  char message[LOG_MESSAGE_SIZE];
+#endif
 
   g_return_val_if_fail(request != NULL, FALSE);
 
@@ -2577,8 +2661,8 @@ ochusha_network_broker_try_post(OchushaNetworkBroker *broker,
 #if 0
   ghttp_set_header(request, http_hdr_Accept, "text/xml,application/xml,application/xhtml+xml,text/html;q=0.9,text/plain;q=0.8,video/x-mng,image/png,image/jpeg,image/gif;q=0.2,text/css,*/*;q=0.1");
   ghttp_set_header(request, http_hdr_Accept_Language, "ja,en-us;q=0.66,en;q=0.33");
-  ghttp_set_header(request, http_hdr_Accept_Charset, "EUC-JP,utf-8;q=0.66,*;q=0.66");
 #endif
+  ghttp_set_header(request, http_hdr_Accept_Charset, "Shift_JIS,EUC-JP,utf-8;q=0.66,*;q=0.66");
 
   ghttp_set_header(request, http_hdr_Connection, "close");
   ghttp_set_header(request, http_hdr_Referrer, referer);
@@ -2587,12 +2671,20 @@ ochusha_network_broker_try_post(OchushaNetworkBroker *broker,
   if (cookie != NULL)
     ghttp_set_header(request, "Cookie", cookie);
 
+#if DEBUG_POST
+  snprintf(message, LOG_MESSAGE_SIZE, _("Posting a response: %s\n"), url);
+  ochusha_network_broker_output_log(broker, message);
+#endif
+
   ghttp_set_body(request, (char *)body, strlen(body));
   ghttp_prepare(request);
 
   if (ghttp_process(request) == ghttp_error)
     {
 #if DEBUG_POST
+      ochusha_network_broker_output_log(broker, _("Posting failed: ghttp_process() returns ghttp_error\n"));
+#endif
+#if DEBUG_POST_MOST
       fprintf(stderr, "ghttp_process() returns ghttp_error\n");
 #endif
       ghttp_request_destroy(request);
@@ -2617,10 +2709,34 @@ ochusha_network_broker_try_post(OchushaNetworkBroker *broker,
 	status->set_cookie = G_STRDUP(set_cookie);
       else
 	status->set_cookie = NULL;
+#if DEBUG_NETWORK
+      {
+	int i;
+	char **headers = NULL;
+	int num_headers = 0;
+	snprintf(message, LOG_MESSAGE_SIZE, "Status: %s (%d)\n",
+		 ghttp_reason_phrase(request), status->status_code);
+	ochusha_network_broker_output_log(broker, message);
+	ghttp_get_header_names(request, &headers, &num_headers);
+	for (i = 0; i < num_headers; i++)
+	  {
+	    snprintf(message, LOG_MESSAGE_SIZE, "%s: %s\n",
+		     headers[i], ghttp_get_header(request, headers[i]));
+	    ochusha_network_broker_output_log(broker, message);
+	    free(headers[i]);
+	  }
+	if (headers != NULL)
+	  free(headers);
+      }
+#endif
     }
 
   ghttp_request_destroy(request);
 
+#if DEBUG_POST
+  ochusha_network_broker_output_log(broker, _("Posting done.\n"));
+#endif
+
   return TRUE;
 }
 
