@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_private.h,v 1.9 2003/11/26 06:43:43 fuyu Exp $
+ * $Id: ochusha_private.h,v 1.11 2003/12/14 20:06:42 fuyu Exp $
  */
 
 #ifndef _OCHUSHA_PRIVATE_H_
@@ -46,6 +46,9 @@
 #define DEBUG_ICONV_MOST	0
 #define DEBUG_UTILS		0
 
+#define DEBUG_NETWORK		0
+#define DEBUG_NETWORK_MOST	0
+
 #define DEBUG_POST		0
 #define DEBUG_POST_MOST		0
 
